@@ -60,7 +60,7 @@ class HltMkab(BaseModel):
     oms_okved = models.ForeignKey('OmsOkved', models.DO_NOTHING, db_column='rf_omsOKVEDID')
     soc_status = models.ForeignKey('OmsKlSocStatus', db_column='rf_kl_SocStatusID', **FK_DEFAULT)
     sex_id = models.IntegerField(db_column='rf_kl_SexID')
-    health_group_id = models.IntegerField(db_column='rf_kl_HealthGroupID')
+    health_group = models.ForeignKey('OmsKlHealthGroup', db_column='rf_kl_HealthGroupID', **FK_DEFAULT)
     address_live = models.ForeignKey('KlaAddress', db_column='rf_AddressLiveID', **FK_DEFAULT)
     address_reg = models.ForeignKey('KlaAddress', db_column='rf_AddressRegID', **FK_DEFAULT)
     address_work = models.ForeignKey('KlaAddress', db_column='rf_AddressWorkID', **FK_DEFAULT)
