@@ -44,7 +44,7 @@ class HltTap(BaseModel):
     visit_result = models.ForeignKey('OmsKlVisitResult', db_column='rf_kl_VisitResultID', **FK_DEFAULT)
     registration_end_reason_id = models.IntegerField(db_column='rf_kl_RegistrationEndReasonID')
     registration_end_reason2_id = models.IntegerField(db_column='rf_kl_RegistrationEndReason2ID')
-    health_group_id = models.IntegerField(db_column='rf_kl_HealthGroupID')
+    health_group = models.ForeignKey('OmsKlHealthGroup', db_column='rf_kl_HealthGroupID', **FK_DEFAULT)
     visit_place = models.ForeignKey('OmsKlVisitPlace', db_column='rf_kl_VisitPlaceID', **FK_DEFAULT)
     reason_type = models.ForeignKey('OmsKlReasonType', db_column='rf_kl_ReasonTypeID', **FK_DEFAULT)
     department = models.ForeignKey('OmsDepartment', db_column='rf_DepartmentID', **FK_DEFAULT)
